@@ -13,8 +13,8 @@ class Encoder(JSONEncoder):
         if hasattr(obj, 'to_json'):
             return obj.to_json()
         elif hasattr(obj, '__dict__'):
-            return {key: val for key, val in getmembers(obj)
-                    if not any((key.startswith('_'), callable(val), key == 'metadata'))}
+            return {key: {"name": val.name, "value": val.value} if key == "result_type" else val
+                    for key, val in getmembers(obj) if not any((key.startswith('_'), callable(val), key == 'metadata'))}
         elif hasattr(obj, 'isoformat'):
             return f"{obj.isoformat(timespec='milliseconds')}Z"
         elif type(obj).__name__ == 'ndarray':
